@@ -36,7 +36,8 @@ class CreateBranch:
 
         self._checkout_branch(issue)
 
-        self._youtrack.assign_to(issue["id"], "me")
+        user = self._youtrack.get_current_user()
+        self._youtrack.assign_to(issue["id"], user["login"])
 
         self._youtrack.update_state(issue["id"], self._config.youtrack["picked_state"])
 
